@@ -3,6 +3,6 @@ package TestCGIBin;
 use Catalyst::Runtime '5.70';
 use parent 'Catalyst';
 
-__PACKAGE__->setup;
+__PACKAGE__->setup(qw/Static::Simple/);
 
 1;
